@@ -1,5 +1,5 @@
 package HackaMol::Roles::ReadZmatRole;
-$HackaMol::Roles::ReadZmatRole::VERSION = '0.020';
+$HackaMol::Roles::ReadZmatRole::VERSION = '0.021';
 # ABSTRACT: Read files with molecular information
 use Moo::Role;
 use strictures 2;
@@ -25,14 +25,7 @@ sub read_zmat_atoms {
     my $nat  = undef;
   
     my @zmat = <$fh>;
-    @zmat = _collapse(@zmat);
-    chomp @zmat;
-    my @var  = grep {/=/} @zmat;
-    @zmat    = grep {!/(^\#)|(^\s*$)/} @zmat;
-    chomp @zmat;
-
-    #use Data::Dumper; 
-    #print Dumper \@zmat; exit;
+    @zmat = _substitute_variables(@zmat);
 
     # we have 5 types of extensions
     # A. SYM 0 x y z
@@ -45,18 +38,31 @@ sub read_zmat_atoms {
     #type A
     my @iA = grep { $zmat[$_] =~ m/^\s*\w+\s+0(\s+-*\d*\.*\d*){3}/ } 0 .. $#zmat;
     my @inA = singleton( 0 .. $#zmat, @iA );
+
     #type B
     my @iB = grep { $zmat[$_] =~ m/^\s*\w+\s*$/ } @inA;
+
     #type C
     my @iC = grep { $zmat[$_] =~ m/^\s*\w+(\s+\d+\s+\d*\.*\d*)\s*$/ } @inA;
+
     #type D
     my @iD = grep { $zmat[$_] =~ m/^\s*\w+(\s+\d+\s+\d*\.*\d*){2}\s*$/ } @inA;
+
     #type E
     my @iE = grep {
         $zmat[$_] =~ m/^\s*\w+(\s+\d+\s+\d*\.*\d*){2}\s+\d+\s+-*\d*\.*\d*\s*$/
     } @inA;
+
     my $diff = @zmat - (@iA+@iB+@iC+@iD+@iE); #scalar context
-    croak "something funky with your zmatrix: $diff" if ( $diff );
+    
+    if ($diff){
+      print "Lines in Z-matrix: ", scalar (@zmat), " Number of lines to be processed: ", scalar (@zmat) - $diff, "\n";
+      print "Lines missed: ", $diff, "\n";
+      print "\n\nHere is your Z-matrix:\n";
+      print $_ foreach @zmat;
+      print "Indices of lines to be processed: ", join("\n", @iA, @iB, @iC, @iD, @iE);      
+      croak "\nThere is something funky with your zmatrix";
+    }
 
     foreach my $ia (@iA) {
         my ( $sym, $iat1, @xyz ) = split( ' ', $zmat[$ia] );
@@ -124,25 +130,31 @@ sub read_zmat_atoms {
 
 }
 
-sub _collapse{
+sub _substitute_variables{
     my @Zmat = @_;
 
     chomp @Zmat;
 
+    my %bin;
     my %var  =  map {
                       my ($key,$val) = map{ s/^\s+|\s+$//; $_ } split(/\s*=\s*/,$_);
+                      $bin{$key}++;
                       $key => $val,
-                    }
-                grep {/=/} @Zmat;
+                    } grep {/=/} @Zmat;
 
-    @Zmat    = grep {!/^\#|=/} @Zmat;
+    # check for double entry of variables
+    my @too_many = grep {$bin{$_}>1} keys(%bin);     
+    if (@too_many) {
+      carp "ReadZMatRole> you have more than one entry for these variables: ". join("\n", @too_many);
+    }
+
+    @Zmat    = grep {!/(^\#)|=|(^\s*$)/} @Zmat;
 
     foreach my $line (@Zmat){
       my @vals = split (/ /, $line);
       next unless @vals > 2;
       $line = join(' ', $vals[0], map{ exists($var{$_}) ? $var{$_} : $_ } @vals[1 .. $#vals] );
     }
-    # print Dump \@Zmat;
     return (@Zmat);
 }
 
@@ -158,67 +170,39 @@ HackaMol::Roles::ReadZmatRole - Read files with molecular information
 
 =head1 VERSION
 
-version 0.020
+version 0.021
 
 =head1 SYNOPSIS
 
-   use HackaMol;
-
-   my $hack   = HackaMol->new( name => "hackitup" );
-
-   # build array of carbon atoms from pdb [xyz,pdbqt] file
-   my @carbons  = grep {
-                        $_->symbol eq "C"
-                       } $hack->read_file_atoms("t/lib/1L2Y.pdb"); 
-
-   my $Cmol     = HackaMol::Molecule->new(
-                        name => "carbonprotein", 
-                        atoms => [ @carbons ]
-                  );
-
-   $Cmol->print_pdb;   
-   $Cmol->print_xyz;     
-
-   # build molecule from xyz [pdb,pdbqt] file
-   my $mol    = $hack->read_file_mol("some.xyz");
-   $mol->print_pdb; # not so easy from xyz to pdb! 
+   my @atoms = HackaMol->new
+                       ->read_zmat_atoms("some.zmat");
 
 =head1 DESCRIPTION
 
-The HackaMol::MolReadRole role provided methods for reading common structural files.  Currently,
-pdb and xyz are provided in the core, but others will be likely added.  
+The HackaMol::Roles::ReadZmatRole provides read_zmat_atoms for the flexible reading of Z-matrix files. 
+It supports inline cartesian coordinates and variables as in the following example:
+
+N 0     -12.781   3.620  15.274 
+C 0     -11.976   4.652  15.944 
+C 0     -12.722   6.019  15.985 
+O 0     -13.133   6.378  14.897 
+C 2  CBCA 3 CBCAC 4 CBCACO 
+C 5  CBCA 2 CBCAC 3 CG1CBCAC
+C 5  CBCA 2 CBCAC 3 CG2CBCAC
+CBCA    = 1.54
+CBCA    = 1.54
+CBCA    = 1.54
+CBCAC   = 113.4
+CBCACO  = 71.85
+CG1CBCAC = 54. 
+CG2CBCAC = 180.
 
 =head1 METHODS
 
-=head2 read_file_atoms
+=head2 read_zmat_atoms
 
-takes the name of the file as input, parses the file, builds Atom objects, and returns them.
-Matches the filename extension and calls on either read_pdb_atoms or read_xyz_atoms
-
-=head2 read_pdb_atoms
-
-takes the name of the file as input, parses the pdb file to return the list of built 
-Atom objects. This is a barebones parser.  A more advanced PDB parser will be released 
-soon as an extension. 
-
-According to the PDB specification, the element symbol should be present in columns 77-78.  
-The element is often ommitted by programs, such as charmm, that can write pdbs because it makes the
-file larger, and the information is accessible somewhere else. Unfortunately, other programs require
-the information.  HackaMol::MolReadRole, loads a hash (KNOWN_NAMES) from HackaMol::PeriodicTable 
-that maps common names to the element (e.g. POT => 'K'). read_pdb_atoms will carp if the name is 
-not in the hash, and then set the element to the first letter of the name. This will be improved when
-HackaMol::PeriodicTable is improved. See TODO.
-
-=head2 read_xyz_atoms
-
-takes the name of the file as input, parses the xyz file to return the list of built 
-Atom objects.  
-
-=head1 ATTRIBUTES
-
-=head2 hush_read
-
-isa Bool that is lazy. $hack->hush_read(1) will quiet some warnings that may be ignored under some instances.
+One argument: the filename
+Returns a list of HackaMol::Atom objects.
 
 =head1 SEE ALSO
 
@@ -230,7 +214,15 @@ L<HackaMol>
 
 =item *
 
-L<Protein Data Bank | http://pdb.org>
+L<HackaMol::Atom>
+
+=item *
+
+L<HackaMol::Roles::MolReadRole>
+
+=item *
+
+L<Protein Data Bank|http://pdb.org>
 
 =back
 
